# Generated by Django 2.2.27 on 2022-03-31 17:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('register', '0013_visa'),
    ]

    operations = [
        migrations.AddField(
            model_name='attendee',
            name='confirm_covid_tests',
            field=models.BooleanField(null=True),
        ),
    ]
