# Generated by Django 2.2.27 on 2022-03-16 00:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('register', '0011_add_address'),
    ]

    operations = [
        migrations.AddField(
            model_name='attendee',
            name='vaccinated',
            field=models.BooleanField(null=True),
        ),
        migrations.AddField(
            model_name='attendee',
            name='vaccination_notes',
            field=models.TextField(blank=True),
        ),
    ]
