{% extends 'wafer/base.html' %}
{% load countries %}

{% block content %}
<h1>Conference Statistics</h1>
<ul>
  <li><a href="{% url 'register-statistics' %}">Registration Statistics</a></li>
  <li><a href="{% url 'content-statistics' %}">Content Statistics</a></li>
  <li><a href="{% url 'wafer_volunteer_statistics' %}">Volunteer Statistics</a></li>
</ul>
{% endblock content %}
