# Generated by Django 2.2.14 on 2020-07-05 23:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bursary', '0002_update_fk'),
    ]

    operations = [
        migrations.AddField(
            model_name='bursary',
            name='expenses_status',
            field=models.CharField(choices=[('submitted', 'The bursary request has been submitted'), ('ranked', 'The bursary request has been ranked'), ('pending', 'The bursary request has been granted and is pending your acceptance'), ('accepted', 'The bursary has been accepted'), ('denied', 'The bursary has been denied'), ('expired', 'The bursary grant has expired'), ('canceled', 'The bursary request has been canceled')], default='submitted', max_length=32),
        ),
        migrations.AddField(
            model_name='bursary',
            name='request_expenses',
            field=models.BooleanField(default=False),
            preserve_default=False,
        ),
    ]
